@@ -29,6 +29,8 @@
 #include "nautilus-lib-self-check-functions.h"
 #include "nautilus-metadata.h"
 #include "nautilus-metafile.h"
+#include "nautilus-file.h"
+#include "nautilus-search-directory.h"
 #include <eel/eel-glib-extensions.h>
 #include <eel/eel-string.h>
 #include <eel/eel-vfs-extensions.h>
@@ -47,6 +49,58 @@
 #define LEGACY_DESKTOP_DIRECTORY_NAME ".gnome-desktop"
 #define DEFAULT_DESKTOP_DIRECTORY_MODE (0755)
 
+
+char *
+nautilus_compute_title_for_uri (const char *text_uri)
+{
+	NautilusFile *file;
+	GnomeVFSURI *uri;
+	char *title, *displayname;
+	const char *hostname;
+	NautilusDirectory *directory;
+	NautilusQuery *query;
+	hostname = NULL;
+
+	if (text_uri) {
+		if (eel_uri_is_search (text_uri)) {
+			directory = nautilus_directory_get (text_uri);
+			
+			query = nautilus_search_directory_get_query (NAUTILUS_SEARCH_DIRECTORY (directory));
+			nautilus_directory_unref (directory);
+			
+			if (query != NULL) {
+				title = nautilus_query_to_readable_string (query);
+				g_object_unref (query);
+			} else {
+				title = g_strdup (_("Search"));
+			}
+
+			return title;
+		}
+		file = nautilus_file_get (text_uri);
+		uri = gnome_vfs_uri_new (text_uri);
+		if (uri && !gnome_vfs_uri_is_local (uri)) {
+			hostname = gnome_vfs_uri_get_host_name (uri);
+		}
+		displayname = nautilus_file_get_display_name (file);
+		if (hostname) {
+			title = g_strdup_printf (_("%s on %s"), displayname, hostname);
+			g_free (displayname);
+		} else {
+			title = displayname;
+		}
+		if (uri) {
+			gnome_vfs_uri_unref (uri);
+		}
+		nautilus_file_unref (file);
+	} else {
+		title = g_strdup ("");
+	}
+	
+	return title;
+}
+
+
 gboolean
 nautilus_file_name_matches_hidden_pattern (const char *name_or_relative_uri)
 {
@@ -60,7 +114,8 @@ nautilus_file_name_matches_backup_pattern (const char *name_or_relative_uri)
 {
 	g_return_val_if_fail (name_or_relative_uri != NULL, FALSE);
 
-	return eel_str_has_suffix (name_or_relative_uri, "~");
+	return g_str_has_suffix (name_or_relative_uri, "~") &&
+	       !g_str_equal (name_or_relative_uri, "~");
 }
 
 /**
@@ -169,6 +224,13 @@ nautilus_get_desktop_directory_uri_no_create (void)
 	return desktop_uri;
 }
 
+char *
+nautilus_get_home_directory_uri (void)
+{
+	return  gnome_vfs_get_uri_from_local_path (g_get_home_dir ());
+}
+
+
 char *
 nautilus_get_templates_directory (void)
 {
@@ -199,6 +261,22 @@ nautilus_get_templates_directory_uri (void)
 	return uri;
 }
 
+char *
+nautilus_get_searches_directory (void)
+{
+	char *user_dir;
+	char *searches_dir;
+
+	user_dir = nautilus_get_user_directory ();
+	searches_dir = g_build_filename (user_dir, "searches", NULL);
+	g_free (user_dir);
+	
+	if (!g_file_test (searches_dir, G_FILE_TEST_EXISTS))
+		mkdir (searches_dir, DEFAULT_NAUTILUS_DIRECTORY_MODE);
+
+	return searches_dir;
+}
+
 /* These need to be reset to NULL when desktop_is_home_dir changes */
 static char *escaped_desktop_dir = NULL;
 static char *escaped_desktop_dir_dirname = NULL;
@@ -451,6 +529,7 @@ nautilus_get_vfs_method_display_name (char *method)
 	} else if (g_ascii_strcasecmp (method, "smb") == 0 ) {
 		return _("Windows Network");
 	} else if (g_ascii_strcasecmp (method, "dns-sd") == 0 ) {
+		/* translators: this is the title of the "dns-sd:///" location */
 		return _("Services in");
 	}
 	return NULL;
