@@ -36,6 +36,7 @@
 #include <eel/eel-gnome-extensions.h>
 #include <libnautilus-private/nautilus-icon-factory.h>
 #include <libnautilus-private/nautilus-undo-signal-handlers.h>
+#include <gtk/gtkenums.h>
 #include <gtk/gtkhbbox.h>
 #include <gnome.h>
 #include <libgnomeui/gnome-help.h>
@@ -778,6 +779,8 @@ update_bookmark_from_text (void)
 {
 	if (text_changed) {
 		NautilusBookmark *bookmark, *bookmark_in_list;
+		char *name;
+		GdkPixbuf *pixbuf;
 		guint selected_row;
 		GtkTreeIter iter;
 
@@ -809,13 +812,24 @@ update_bookmark_from_text (void)
 						 NULL, &iter);
 		g_signal_handler_block (bookmark_list_store,
 					row_changed_signal_id);
+
 		bookmark_in_list = nautilus_bookmark_list_item_at (bookmarks,
 								   selected_row);
+
+		name = nautilus_bookmark_get_name (bookmark_in_list);
+
+		pixbuf = nautilus_bookmark_get_pixbuf (bookmark_in_list, GTK_ICON_SIZE_MENU);
+
 		gtk_list_store_set (bookmark_list_store, &iter,
 				    BOOKMARK_LIST_COLUMN_BOOKMARK, bookmark_in_list,
+				    BOOKMARK_LIST_COLUMN_NAME, name,
+				    BOOKMARK_LIST_COLUMN_ICON, pixbuf,
 				    -1);
 		g_signal_handler_unblock (bookmark_list_store,
 					  row_changed_signal_id);
+
+		gdk_pixbuf_unref (pixbuf);
+		g_free (name);
 	}
 }
 
@@ -933,9 +947,7 @@ repopulate (void)
 
 		bookmark = nautilus_bookmark_list_item_at (bookmarks, index);
 		bookmark_name = nautilus_bookmark_get_name (bookmark);
-		bookmark_pixbuf = nautilus_bookmark_get_pixbuf (bookmark,
-								NAUTILUS_ICON_SIZE_SMALLER,
-								TRUE);
+		bookmark_pixbuf = nautilus_bookmark_get_pixbuf (bookmark, GTK_ICON_SIZE_MENU);
 		
 		gtk_list_store_append (store, &iter);
 		gtk_list_store_set (store, &iter, 
