@@ -553,7 +553,6 @@ receive_dropped_uri_list (NautilusInformationPanel *information_panel,
 			eel_show_error_dialog (
 				_("You can't assign more than one custom icon at a time."),
 				_("Please drag just one image to set a custom icon."), 
-				_("More Than One Image"),
 				window);
 			break;
 		}
@@ -574,14 +573,12 @@ receive_dropped_uri_list (NautilusInformationPanel *information_panel,
 				eel_show_error_dialog (
 					_("The file that you dropped is not local."),
 					_("You can only use local images as custom icons."), 
-					_("Local Images Only"),
 					window);
 			
 			} else {
 				eel_show_error_dialog (
 					_("The file that you dropped is not an image."),
 					_("You can only use images as custom icons."),
-					_("Images Only"),
 					window);
 			}
 		}	
@@ -855,13 +852,17 @@ command_button_callback (GtkWidget *button, char *id_str)
 {
 	NautilusInformationPanel *information_panel;
 	GnomeVFSMimeApplication *application;
+	GList files;
 	
 	information_panel = NAUTILUS_INFORMATION_PANEL (g_object_get_data (G_OBJECT (button), "user_data"));
 
 	application = gnome_vfs_mime_application_new_from_desktop_id (id_str);
 
 	if (application != NULL) {
-		nautilus_launch_application (application, information_panel->details->file,
+		files.next = NULL;
+		files.prev = NULL;
+		files.data = information_panel->details->file;
+		nautilus_launch_application (application, &files,
 					     nautilus_information_panel_get_window (information_panel));	
 
 		gnome_vfs_mime_application_free (application);
@@ -991,7 +992,6 @@ burn_cd_callback (GtkWidget *button, gpointer data)
 			    NULL,
 			    &error)) {
 		eel_show_error_dialog (_("Unable to launch the cd burner application."), error->message,
-				       _("Can't Launch CD Burner"),
 				       GTK_WINDOW (gtk_widget_get_toplevel (button)));
 		g_error_free (error);
 	}
